@@ -2,15 +2,16 @@
 
 #include <QList>
 
-Bookmark::Bookmark() :
-    m_title(QString::null),
-    m_url(QString::null)
+Bookmark::Bookmark()
 {
+    m_title = QString::null;
+    m_url = QString::null;
 }
 
 Bookmark::Bookmark(QString title, QString url) :
-    m_title(title),
-    m_url(url)
+    m_url(url),
+    m_title(title)
+
 {
 }
 
