@@ -22,33 +22,22 @@
 
 MainWindow::MainWindow(MainWindow *pParent) :
     QMainWindow(),
-    // m_pUI(new Ui::MainWindow),
     m_webPage(this)
 {
+    m_pGraphicsView = NULL;
+    m_pGWebView = NULL;
+    m_pWebView = NULL;
+    m_isUsingGraphicsView = false;
+
     setWindowTitle("Macuco");
     m_pParent = pParent;
-    // m_pUI->setupUi(this);
 
-#ifdef WEBGRAPHICS
-    m_pGraphicsView = new WebGraphicsView();
-    m_pView = new QGraphicsWebView();
-    m_pGraphicsView->viewportItem()->setWidget(m_pView);
-    setCentralWidget(m_pGraphicsView);
-#else
-    m_pView = new WebView(this);
-    setCentralWidget(m_pView);
-#endif
+    createMenu();
 
     // loading label...
     m_pLoadingLabel = new QLabel(this);
     m_pLoadingLabel->setPixmap( QPixmap(QString::fromUtf8(":/images/spinner.png")) );
 
-    menuBar()->addAction("Home", this, SLOT(on_actionHome_triggered()));
-    menuBar()->addAction("Go To...", this, SLOT(on_actionGo_To_triggered()));
-    menuBar()->addAction("Bookmarks", this, SLOT(on_actionBookmarks_triggered()));
-    menuBar()->addAction("Add Bookmark", this, SLOT(on_actionAdd_Bookmark_triggered()));
-
-
 #ifdef Q_WS_MAEMO_5
     FullScreenExitButton *pButt = new FullScreenExitButton(this);
     connect(pButt, SIGNAL(clicked()), this, SLOT(showNormal()));
@@ -57,20 +46,6 @@ MainWindow::MainWindow(MainWindow *pParent) :
 
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    menuBar()->addAction("Fullscreen", this, SLOT(fullscreen_triggered()));
-
-    m_pOrientationSelector = new PickSelectorAction(this);
-    m_pOrientationSelector->setText("Orientation");
-    m_pOrientationSelector->items() << "Auto" << "Landscape" << "Portrait";
-    connect(m_pOrientationSelector, SIGNAL(selectionChanged(int)), this, SLOT(orientation_selectionChanged(int)));
-    menuBar()->addAction(m_pOrientationSelector);
-
-    m_pUserAgentSelector = new PickSelectorAction(this);
-    m_pUserAgentSelector->setText("User Agent");
-    m_pUserAgentSelector->items() << "IPhone" << "Default";
-    connect(m_pUserAgentSelector, SIGNAL(selectionChanged(int)), this, SLOT(userAgent_selectionChanged(int)));
-    menuBar()->addAction(m_pUserAgentSelector);
-
 #else // !Q_WS_MAEMO_5
     // error box
     m_pErrorBox = new ErrorBox(this);
@@ -92,13 +67,6 @@ MainWindow::MainWindow(MainWindow *pParent) :
     connect(m_pToolbar->getReloadButton(), SIGNAL(clicked()), m_pView, SLOT(reload()));
 
     connect(m_pToolbar, SIGNAL(urlChanged(QString)), this, SLOT(visitUrl(QString)));
-
-    QAction *pFullscreen = menuBar()->addAction("Fullscreen");
-    pFullscreen->setCheckable(true);
-    connect(pFullscreen, SIGNAL(toggled(bool)), this, SLOT(setFullScreen(bool)));
-
-    // user agent
-    // ...
 #endif
 
     if ( m_pParent ) {
@@ -122,12 +90,6 @@ MainWindow::MainWindow(MainWindow *pParent) :
         loadSettings();
     }
 
-#ifndef WEBGRAPHICS
-    // set web page
-    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
-    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
-#endif
-
     connect(m_webPage.networkAccessManager(), SIGNAL(finished(QNetworkReply*)),
         this, SLOT(finishedRequest(QNetworkReply*)));
 
@@ -145,13 +107,13 @@ MainWindow::MainWindow(MainWindow *pParent) :
     connect(&m_webPage, SIGNAL(unsupportedContent(QNetworkReply*)), this, SLOT(unsupportedContent(QNetworkReply*)));
     connect(&m_webPage, SIGNAL(downloadRequested(QNetworkRequest)), this, SLOT(downloadRequested(QNetworkRequest)));
 
-    connect(m_pView, SIGNAL(loadStarted()), this, SLOT(showLoading()));
-    connect(m_pView, SIGNAL(urlChanged(QUrl)), this, SLOT(changeUrl(QUrl)));
-    connect(m_pView, SIGNAL(loadFinished(bool)), this, SLOT(hideLoading(bool)));
-
-    m_pView->setPage(&m_webPage);
-
-    if ( !m_pParent ) visitUrl("http://www.crochik.com/macuco");
+    if ( !m_pParent ) {
+        setWidget();
+        visitUrl("http://www.crochik.com/macuco");
+    } else {
+        m_isUsingGraphicsView = m_pParent->m_isUsingGraphicsView;
+        setWidget();
+    }
 }
 
 MainWindow::~MainWindow()
@@ -170,6 +132,102 @@ MainWindow::~MainWindow()
     while ( !m_children.isEmpty() ) delete m_children.takeLast();
 }
 
+void MainWindow::createMenu() {
+    menuBar()->addAction("Home", this, SLOT(on_actionHome_triggered()));
+    menuBar()->addAction("Go To...", this, SLOT(on_actionGo_To_triggered()));
+    menuBar()->addAction("Bookmarks", this, SLOT(on_actionBookmarks_triggered()));
+    menuBar()->addAction("Add Bookmark", this, SLOT(on_actionAdd_Bookmark_triggered()));
+
+#ifdef Q_WS_MAEMO_5
+    menuBar()->addAction("Fullscreen", this, SLOT(fullscreen_triggered()));
+
+    m_pOrientationSelector = new PickSelectorAction(this);
+    m_pOrientationSelector->setText("Orientation");
+    m_pOrientationSelector->items() << "Auto" << "Landscape" << "Portrait";
+    connect(m_pOrientationSelector, SIGNAL(selectionChanged(int)), this, SLOT(orientation_selectionChanged(int)));
+    menuBar()->addAction(m_pOrientationSelector);
+
+    m_pUserAgentSelector = new PickSelectorAction(this);
+    m_pUserAgentSelector->setText("User Agent");
+    m_pUserAgentSelector->items() << "IPhone" << "Default";
+    connect(m_pUserAgentSelector, SIGNAL(selectionChanged(int)), this, SLOT(userAgent_selectionChanged(int)));
+    menuBar()->addAction(m_pUserAgentSelector);
+#else
+    QAction *pFullscreen = menuBar()->addAction("Fullscreen");
+    pFullscreen->setCheckable(true);
+    connect(pFullscreen, SIGNAL(toggled(bool)), this, SLOT(setFullScreen(bool)));
+
+    // user agent
+    // ...
+
+#endif
+
+#ifdef QT_DEBUG
+    menuBar()->addAction("Switch View", this, SLOT(switchView()));
+    menuBar()->addAction("About Qt..", this, SLOT(aboutQt()));
+#endif
+}
+
+void MainWindow::switchView() {
+    m_isUsingGraphicsView = !m_isUsingGraphicsView;
+    setWidget();
+}
+
+void MainWindow::setWidget() {
+    if ( m_isUsingGraphicsView ) {
+        qDebug() << "Switch to Graphics View";
+        if ( m_pWebView ) {
+            qDebug() << ">> delete WebView";
+            delete m_pWebView; m_pWebView = NULL;
+        }
+
+        if ( !m_pGWebView ) {
+            // using graphics view
+            m_pGraphicsView = new GraphicsView(this);
+            m_pGWebView = new QGraphicsWebView();
+            m_pGraphicsView->viewportItem()->setWidget(m_pGWebView);
+            m_pGWebView->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
+
+            connect(m_pGWebView, SIGNAL(loadStarted()), this, SLOT(showLoading()));
+            connect(m_pGWebView, SIGNAL(urlChanged(QUrl)), this, SLOT(changeUrl(QUrl)));
+            connect(m_pGWebView, SIGNAL(loadFinished(bool)), this, SLOT(hideLoading(bool)));
+        }
+
+        m_pGWebView->setPage(&m_webPage);
+        setCentralWidget(m_pGraphicsView);
+
+        if ( !m_currentUrl.isEmpty() ) reload();
+        return;
+    }
+
+    qDebug() << "Switch to Web View";
+    if ( m_pGWebView ) {
+        qDebug() << ">> delete Graphics View";
+        delete m_pGWebView; m_pGWebView = NULL;
+        delete m_pGraphicsView; m_pGraphicsView = NULL;
+    }
+
+    if ( !m_pWebView ) {
+        // using web view
+        m_pWebView = new WebView(this);
+
+        connect(m_pWebView, SIGNAL(loadStarted()), this, SLOT(showLoading()));
+        connect(m_pWebView, SIGNAL(urlChanged(QUrl)), this, SLOT(changeUrl(QUrl)));
+        connect(m_pWebView, SIGNAL(loadFinished(bool)), this, SLOT(hideLoading(bool)));
+    }
+
+    // set web page
+    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
+    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
+
+    m_pWebView->setPage(&m_webPage);
+    setCentralWidget(m_pWebView);
+}
+
+void MainWindow::aboutQt() {
+    QMessageBox::aboutQt(this, "Qt");
+}
+
 void MainWindow::userAgent_selectionChanged(int index) {
     switch ( index ) {
         case 0: // iphone
@@ -183,6 +241,7 @@ void MainWindow::userAgent_selectionChanged(int index) {
 }
 
 void MainWindow::orientation_selectionChanged(int index) {
+#ifdef Q_WS_MAEMO_5
     switch ( index ) {
         case 0: // auto
             setAutoRotate(true);
@@ -198,6 +257,7 @@ void MainWindow::orientation_selectionChanged(int index) {
             setLandscape(false);
             break;
     }
+#endif
 }
 
 MainWindow* MainWindow::topMost() {
@@ -216,6 +276,8 @@ MainWindow* MainWindow::createWindow() {
 }
 
 void MainWindow::loadSettings() {
+    qDebug() << "load settings";
+
     Bookmark::registerMeataType();
 
     QSettings settings("Macuco", "Macuco");
@@ -233,6 +295,8 @@ void MainWindow::loadSettings() {
     int orientation = settings.value("orientation", 0).toInt();
     orientation_selectionChanged(orientation);
 #endif
+
+    qDebug() << ">> done";
 }
 
 void MainWindow::saveSettings() {
@@ -282,12 +346,18 @@ void MainWindow::changeUrl(QUrl url)
 void MainWindow::visitUrl(QString url)
 {
     if ( url.isNull() || url.isEmpty() ) return;
-    m_pView->load(QUrl::fromUserInput(url));
+    if ( m_isUsingGraphicsView )
+        m_pGWebView->load(QUrl::fromUserInput(url));
+    else
+        m_pWebView->load(QUrl::fromUserInput(url));
 }
 
 void MainWindow::reload()
 {
-    m_pView->load(m_currentUrl);
+    if ( m_isUsingGraphicsView )
+        m_pGWebView->load(m_currentUrl);
+    else
+        m_pWebView->load(m_currentUrl);
 
 #ifndef Q_WS_MAEMO_5
     m_pErrorBox->hide();
@@ -350,10 +420,15 @@ void MainWindow::setZoom(qreal zoomFactor) {
     m_zoomFactor = zoomFactor;
     if ( m_zoomFactor>.90 && m_zoomFactor<1.1) m_zoomFactor =1;
 
-    m_pView->setZoomFactor(m_zoomFactor);
-
-    if ( m_pGraphicsView )
+    if ( m_isUsingGraphicsView ) {
+        if ( !m_pGWebView ) return;
+        m_pGWebView->setZoomFactor(m_zoomFactor);
         m_pGraphicsView->viewportItem()->resizeWebViewToFrame();
+        return;
+    }
+
+    if ( !m_pWebView ) return;
+    m_pWebView->setZoomFactor(m_zoomFactor);
 }
 
 void MainWindow::keyPressEvent(QKeyEvent *event)
@@ -401,7 +476,7 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
 
 void MainWindow::enableWebkitAutoSize()
 {
-    m_pView->page()->mainFrame()->evaluateJavaScript("document.body.style.WebkitTextSizeAdjust = 'auto'");
+    m_webPage.mainFrame()->evaluateJavaScript("document.body.style.WebkitTextSizeAdjust = 'auto'");
 }
 
 void MainWindow::on_actionHome_triggered() {
@@ -426,11 +501,13 @@ void MainWindow::on_actionBookmarks_triggered()
 
 void MainWindow::setFullScreen(bool full/*=true*/) {
 #ifndef Q_WS_MAEMO_5
+    /*
     if ( m_pUI->actionFullscreen->isChecked()!=full ) {
         // change status of menu item and wait for event to be triggered
         m_pUI->actionFullscreen->setChecked(full);
         return;
     }
+    */
 #endif
 
     if (!full) {
@@ -457,7 +534,7 @@ void MainWindow::on_actionAdd_Bookmark_triggered()
 {
     BookmarkDlg dlg(this);
     dlg.setUrl(m_currentUrl.toString());
-    dlg.setTitle(m_pView->title());
+    dlg.setTitle(m_pGWebView->title());
     dlg.removeBtt()->setVisible(false);
 
     if ( dlg.exec()!= QDialog::Accepted ) return;
@@ -604,7 +681,10 @@ void MainWindow::on_actionUser_Agent_triggered()
 
 void MainWindow::setUserAgent(bool iphone/*=true*/) {
     m_webPage.setIPhoneUserAgent(iphone);
+
+#ifdef Q_WS_MAEMO_5
     m_pUserAgentSelector->setSelectedIndex(iphone?0:1);
+#endif
 }
 
 void MainWindow::linkClicked( const QUrl & url ) {
