@@ -4,21 +4,14 @@
 #include <QtGui/QMainWindow>
 #include <QLabel>
 
-// -----------------------------------------------------------------------
-#define WEBGRAPHICS
-// -----------------------------------------------------------------------
-
-#ifdef WEBGRAPHICS
-    #include <QGraphicsWebView>
-    #include "webgraphicsview.h"
-#else
-    #include "webview.h"
-#endif
-
 #ifdef Q_WS_MAEMO_5
+    #include <QGraphicsWebView>
+    #include "graphicsview.h"
+
     #include "pickselectoraction.h"
 #endif
 
+#include "webview.h"
 #include "errorbox.h"
 #include "toolbar.h"
 #include "minifiedtoolbar.h"
@@ -43,6 +36,8 @@ public:
     MainWindow *createWindow();
     MainWindow *topMost();
 
+    QWebView *getWebView() { return m_pWebView; }
+
 private:
     void loadSettings();
     void saveSettings();
@@ -59,9 +54,10 @@ private:
     void zoomOut();
     void zoomFit();
     void setZoom(qreal zoomFactor);
+    void setWidget();
+    void createMenu();
 
     void enableWebkitAutoSize();
-
     void setUserAgent(bool iphone=true);
 
 #ifdef Q_WS_MAEMO_5
@@ -85,6 +81,8 @@ private slots:
     void on_actionBookmarks_triggered();
     void on_actionHome_triggered();
 
+    void aboutQt();
+    void switchView();
     void setFullScreen(bool full=true);
     void showLoading(); //called when a "loading page" is started
     void changeUrl(QUrl url); //called when the url is changed. The url will be used on the retry action
@@ -104,18 +102,18 @@ private slots:
 #ifdef Q_WS_MAEMO_5
     void orientationChanged();
     void fullscreen_triggered();
-
 #else
     //toolbar visibility control
     void showToolbar();
     void hideToolbar();
-
 #endif
 
     //visit url
     void visitUrl(QString);
 
 private:
+    bool            m_isUsingGraphicsView;
+
     // mainWindow components
     QUrl            m_currentUrl;
     qreal           m_zoomFactor;
@@ -127,14 +125,11 @@ private:
     MainWindow      *m_pParent;
     QList<MainWindow *> m_children;
 
-#ifdef WEBGRAPHICS
+    WebView             *m_pWebView;
+
     // v2
-    QGraphicsWebView    *m_pView;
-    WebGraphicsView     *m_pGraphicsView;
-#else
-    // qt 4.5/not maemo
-    WebView             *m_pView;
-#endif
+    QGraphicsWebView *m_pGWebView;
+    GraphicsView     *m_pGraphicsView;
 
 #ifdef Q_WS_MAEMO_5
     PickSelectorAction  *m_pUserAgentSelector;
